==> haskell-monad-loops-0.4.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-loops.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-loops
version: 0.4.3
id: monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3
key: monad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3
license: PublicDomain
maintainer: James Cook <mokus@deepbondi.net>
stability: provisional
homepage: https://github.com/mokus0/monad-loops
synopsis: Monadic loops
description:
    Some useful control operators for looping.
    .
    New in 0.4: STM loop operators have been split into a
    new package instead of being conditionally-built.
    .
    New in 0.3.2.0: various functions for traversing lists and
    computing minima/maxima using arbitrary procedures to compare
    or score the elements.
category: Control
author: James Cook <mokus@deepbondi.net>
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Loops
abi: 54591a587aa7d5d988ebd34e65b8f537
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/monad-loops-0.4.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/monad-loops-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/monad-loops-0.4.3
hs-libraries: HSmonad-loops-0.4.3-4PsUXmQNk5OJXNWgDnQDQ3
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-monad-loops/html/monad-loops.haddock
haddock-html: /usr/share/doc/haskell-monad-loops/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-loops-0.4.3-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-loops.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-loops
version: 0.4.3
id: monad-loops-0.4.3-4g9tbQ6v5D92QXu31BWMk9
key: monad-loops-0.4.3-4g9tbQ6v5D92QXu31BWMk9
license: PublicDomain
maintainer: James Cook <mokus@deepbondi.net>
stability: provisional
homepage: https://github.com/mokus0/monad-loops
synopsis: Monadic loops
description:
    Some useful control operators for looping.
    .
    New in 0.4: STM loop operators have been split into a
    new package instead of being conditionally-built.
    .
    New in 0.3.2.0: various functions for traversing lists and
    computing minima/maxima using arbitrary procedures to compare
    or score the elements.
category: Control
author: James Cook <mokus@deepbondi.net>
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Loops
abi: a9ba7d22f3e2a7048e828e71a170f3e8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/monad-loops-0.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/monad-loops-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/monad-loops-0.4.3
hs-libraries: HSmonad-loops-0.4.3-4g9tbQ6v5D92QXu31BWMk9
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-monad-loops/html/monad-loops.haddock
haddock-html: /usr/share/doc/haskell-monad-loops/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
